/*
 * Code for class ES_DISCARDABLE_QUESTION_WARNING_PROMPT
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "es5026.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {ES_DISCARDABLE_QUESTION_WARNING_PROMPT}.large_icon */
EIF_REFERENCE F6387_86469 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,Result);
	RTLIU(2);
	
	RTEAA("large_icon", 6386, Current, 0, 0, 90191);
	RTGC;
	RTHOOK(1);
	Result = RTOUCR(858,F1541_21551, (RTCV(RTOUCR(781,F6372_86358, (Current)))));
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

void EIF_Minit5026 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
